;; Generated package description from f90-interface-browser.el  -*- no-byte-compile: t -*-
(define-package "f90-interface-browser" "1.1.0.20201127.235549" "Parse and browse f90 interfaces" 'nil :authors '(("Lawrence Mitchell" . "wence@gmx.li")) :maintainer '("Lawrence Mitchell" . "wence@gmx.li") :url "http://github.com/wence-/f90-iface/")
